@@ -115,6 +115,22 @@
         <source>Some features of MystiQ Video Converter have been inspired by</source>
         <translation>Algunas características de MystiQ Video Converter se han inspirado en</translation>
     </message>
+    <message>
+        <source>Galician (Galicia)</source>
+        <extracomment>Galician Language (Galicia)</extracomment>
+        <translatorcomment>Idioma Gallego (Galicia)</translatorcomment>
+        <translation>Gallego (Galicia)</translation>
+    </message>
+    <message>
+        <source>Icons Theme:&lt;br&gt; %1</source>
+        <translation>Tema de Iconos:&lt;br&gt; %1</translation>
+    </message>
+    <message>
+        <source>Indonesian (Indonesia)</source>
+        <extracomment>Indonesian Language (Indonesia)</extracomment>
+        <translatorcomment>Idioma Indonesio (Indonesia)</translatorcomment>
+        <translation>Indonesio (Indonesia)</translation>
+    </message>
 </context>
 <context>
     <name>AboutFFmpegDialog</name>
@@ -441,6 +457,46 @@
         <source>Rotate 180 degrees</source>
         <translation>Girar 180 grados</translation>
     </message>
+    <message>
+        <source>3D Options</source>
+        <translation>Opciones 3D</translation>
+    </message>
+    <message>
+        <source>Red Blue Gray Monochromatic</source>
+        <translation>Rojo Azul Gris Monocromático</translation>
+    </message>
+    <message>
+        <source>Red Cyan Dubois</source>
+        <translation>Rojo Cyan Madera</translation>
+    </message>
+    <message>
+        <source>Green Magenta Color</source>
+        <translation>Verde Magenta Color</translation>
+    </message>
+    <message>
+        <source>Red Cyan Half Color</source>
+        <translation>Rojo Cyan Semi-Color</translation>
+    </message>
+    <message>
+        <source>Yellow Blue Color</source>
+        <translation>Amarillo Azul Color</translation>
+    </message>
+    <message>
+        <source>Red Cyan Color</source>
+        <translation>Rojo Cyan Color</translation>
+    </message>
+    <message>
+        <source>Green Magenta Gray Monochromatic</source>
+        <translation>Verde Magenta Gris Monocromático</translation>
+    </message>
+    <message>
+        <source>Red Green Gray Monochromatic</source>
+        <translation>Rojo Verde Gris Monocromático</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Sin efecto 3D</translation>
+    </message>
 </context>
 <context>
     <name>ConvertList</name>
@@ -682,9 +738,15 @@ p, li { white-space: pre-wrap; }
 &lt;hr /&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
 &lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file.&lt;/span&gt;&lt;/p&gt;
-&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
+&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -1045,6 +1107,30 @@ p, li { white-space: pre-wrap; }
         <source>Translate Application</source>
         <translation>Traducir Aplicación</translation>
     </message>
+    <message>
+        <source>Report Bugs</source>
+        <translation>Reportar Errores</translation>
+    </message>
+    <message>
+        <source>Email</source>
+        <translation>Email</translation>
+    </message>
+    <message>
+        <source>We need your feedback</source>
+        <translation>Necesitamos sus reportes</translation>
+    </message>
+    <message>
+        <source>Github</source>
+        <translation>Github</translation>
+    </message>
+    <message>
+        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
+        <translation>El equipo de desarrollo de MystiQ Video Converter necesita que los usuarios que usan la aplicación ayuden a la detección de errores. Si usted detecta algún error y lo informa a nuestro equipo, ayudará a acelerar el proceso de corrección. Por lo tanto, puede ser parte de nuestro equipo de desarrollo incluso si no es un programador. Para informar errores, puede enviarnos un correo electrónico con la descripción detallada del mismo o puede ingresar a Github y describirnos el problema (en este caso debe tener creada una cuenta en Github).</translation>
+    </message>
+    <message>
+        <source>Gitter</source>
+        <translation>Gitter</translation>
+    </message>
 </context>
 <context>
     <name>MediaConverter</name>
@@ -1253,5 +1339,13 @@ p, li { white-space: pre-wrap; }
         <source>You can download this version using the link:</source>
         <translation>Puede descargar esta versión usando el enlace:</translation>
     </message>
+    <message>
+        <source>Check Update</source>
+        <translation>Chequear Actualizaciones</translation>
+    </message>
+    <message>
+        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
+        <translation>La actual versión que estás usando es más reciente que la versión del canal de liberación.&lt;br&gt;Por lo tanto, estás usando el canal de desarrollo.</translation>
+    </message>
 </context>
 </TS>
